import simtk.unit as unit
# ParaMol imports
from ParaMol.System.system import *
from ParaMol.MM_engines.openmm import *
import numpy as np



regs = [1.0, 0.1, 0.01, 0.001]

for reg in regs:
    path = "reg_{}/".format(reg)


    # Create the OpenMM engine for aspirin
    openmm_system = OpenMMEngine(init_openmm=True, topology_format='AMBER', top_file=path+'aspirin.prmtop', crd_format="AMBER", crd_file=path+'aspirin.inpcrd',xml_file=path+"aspirin_reparametrized.xml")

    # Create ParaMol System
    aspirin = ParaMolSystem(name="aspirin", engine=openmm_system, n_atoms=21)

    # Read conformations, energies and forces from NETCDF ParaMol file format
    aspirin.read_data(path+"aspirin_reference_data.nc")

    qm_energies = aspirin.ref_forces
    mm_energies = aspirin.get_forces_ensemble()

    rmse = np.sqrt(np.mean(  np.linalg.norm(mm_energies-qm_energies,axis=2) ** 2, axis=0))

    rmse = np.mean(rmse) * 0.1
    print(reg,rmse)




# GAFF
openmm_system = OpenMMEngine(init_openmm=True, topology_format='AMBER', top_file=path+'aspirin.prmtop', crd_format="AMBER", crd_file=path+'aspirin.inpcrd')
# Create ParaMol System
aspirin = ParaMolSystem(name="aspirin", engine=openmm_system, n_atoms=21)
# Read conformations, energies and forces from NETCDF ParaMol file format
aspirin.read_data(path+"aspirin_reference_data.nc")
qm_energies = aspirin.ref_forces
mm_energies = aspirin.get_forces_ensemble()
rmse = np.sqrt(np.mean(  np.linalg.norm(mm_energies-qm_energies,axis=2) ** 2, axis=0))
rmse = np.mean(rmse) * 0.1
print("GAFF", rmse)
