import sys
sys.path.insert(0, "/local/scratch/jm4g18/august2020/ParaMol")

# ParaMol imports
from ParaMol.System.system import *
from ParaMol.MM_engines.openmm import *
from ParaMol.Tasks.adaptive_parametrization import *
from ParaMol.Utils.settings import *
from ParaMol.Utils.amber_symmetrizer import *
from ParaMol.Tasks.ab_initio_properties import *
from ParaMol.Utils.conformational_sampling import *
import numpy as np


# Create ParaMol settings instance
paramol_settings = Settings()

# --------------------------------------------------------- #
#                     Set the QM Engine                     #
# --------------------------------------------------------- #
# Create the ASE calculator
from ase.calculators.dftb import *

calc = Dftb(Hamiltonian_='DFTB',  # line is included by default
			Hamiltonian_MaxAngularMomentum_='',
			Hamiltonian_MaxAngularMomentum_H='s',
			Hamiltonian_MaxAngularMomentum_O='p',
			Hamiltonian_MaxAngularMomentum_C='p',
			Hamiltonian_MaxAngularMomentum_N="p",
			Hamiltonian_Dispersion="DftD3 { \n s6=1.000 \n s8=0.5883 \n Damping = BeckeJohnson { \n a1=0.5719 \n a2=3.6017 \n } \n }",
			Hamiltonian_SCC='Yes',
			Hamiltonian_SCCTolerance=1e-8, )

# Alternative, we could set the calculator in the settings
paramol_settings.qm_engine["ase"]["calculator"] = calc

# --------------------------------------------------------- #
#                         Preparation                       #
# --------------------------------------------------------- #
# Create the OpenMM engine for caffeine
openmm_system = OpenMMEngine(init_openmm=True, topology_format='XML', top_file='caffeine.prmtop', crd_file='caffeine.inpcrd', xml_file="../caffeine_sc_iter_23.xml")

# Create ParaMol System
caffeine = ParaMolSystem(name="caffeine", engine=openmm_system, n_atoms=24)



caffeine.read_data("caffeine_gaff.nc")

mm_energies_after = caffeine.get_energies_ensemble()
mm_forces_after = caffeine.get_forces_ensemble()


atomic_force_error = []
for i in range(24):
    rmsd = np.sqrt(np.mean( np.sum( (caffeine.ref_forces[:,i,:]-mm_forces_after[:,i,:])**2,axis=1)))
    print(i,rmsd)

    atomic_force_error.append(rmsd)


np.savetxt("gaff_b.dat", atomic_force_error)




