import sys
sys.path.insert(0, "/home/treason/PycharmProjects/ParaMol_git_master")


# ParaMol imports
from ParaMol.System.system import *
from ParaMol.MM_engines.openmm import *
from ParaMol.Tasks.adaptive_parametrization import *
from ParaMol.Utils.settings import *
from ParaMol.Tasks.ab_initio_properties import *
from ParaMol.Utils.conformational_sampling import *

from os import environ

# --------------------------------------------------------- #
#                         Preparation                       #
# --------------------------------------------------------- #
# Create the OpenMM engine for caffeine
openmm_system = OpenMMEngine(init_openmm=True, topology_format='AMBER', top_file='caffeine.prmtop', crd_format="AMBER", crd_file='caffeine.inpcrd', xml_file="caffeine_sc_iter_22.xml")

# Create ParaMol System
caffeine = ParaMolSystem(name="caffeine", engine=openmm_system, n_atoms=24)

# Create ParaMol settings instance
paramol_settings = Settings()

# --------------------------------------------------------- #
#                     Set the QM Engine                     #
# --------------------------------------------------------- #
# Create the ASE calculator
from ase.calculators.dftb import *

calc = Dftb(Hamiltonian_='DFTB',  # line is included by default
			Hamiltonian_MaxAngularMomentum_='',
			Hamiltonian_MaxAngularMomentum_H='s',
			Hamiltonian_MaxAngularMomentum_O='p',
			Hamiltonian_MaxAngularMomentum_C='p',
			Hamiltonian_MaxAngularMomentum_N="p",
			Hamiltonian_Dispersion="DftD3 { \n s6=1.000 \n s8=0.5883 \n Damping = BeckeJohnson { \n a1=0.5719 \n a2=3.6017 \n } \n }",
			Hamiltonian_SCC='Yes',
			Hamiltonian_SCCTolerance=1e-8, )

# Alternative, we could set the calculator in the settings
paramol_settings.qm_engine["ase"]["calculator"] = calc


conformational_sampling(paramol_settings, [caffeine], 1000,1000)

caffeine.write_data("caffeine_gaff_mod.nc")

mm_energies_before = caffeine.get_energies_ensemble()
qm_energies = caffeine.ref_energies
rmse_gaff =  np.sqrt(np.mean((mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies)) ** 2))
print("RMSE_GAFF",rmse_gaff,rmse_gaff/4.184)
np.savetxt("qm_energies.dat", qm_energies)
np.savetxt("gaff.dat", mm_energies_before)

