import sys
sys.path.insert(0, "/home/treason/PycharmProjects/ParaMol_git_master")

# ParaMol imports
from ParaMol.System.system import *
from ParaMol.MM_engines.openmm import *
from ParaMol.Tasks.adaptive_parametrization import *
from ParaMol.Utils.settings import *

from ParaMol.Tasks.ab_initio_properties import *


n_struct = 1000
# --------------------------------------------------------- #
#                         Preparation                       #
# --------------------------------------------------------- #
# Create the OpenMM engine for caffeine
openmm_system = OpenMMEngine(init_openmm=True, topology_format='AMBER', top_file='caffeine.prmtop', crd_format='AMBER', crd_file='caffeine.inpcrd')

# Create ParaMol System
caffeine = ParaMolSystem(name="caffeine", engine=openmm_system, n_atoms=24)

# Load data
caffeine.read_data("../gaff/caffeine_gaff.nc")


# Create ParaMol settings instance
paramol_settings = Settings()


caffeine.ref_energies = caffeine.ref_energies[:n_struct]
caffeine.ref_forces = caffeine.ref_forces[:n_struct]
caffeine.ref_coordinates = caffeine.ref_coordinates[:n_struct]
caffeine.n_structures = n_struct

mm_forces_gaff = caffeine.get_forces_ensemble()
qm_forces_gaff = caffeine.ref_forces

atomic_force_error_gaff = np.sqrt(np.mean(np.linalg.norm(mm_forces_gaff-qm_forces_gaff,axis=2)**2,axis=0))


# --------------------------------------------------------- #
#                         Preparation                       #
# --------------------------------------------------------- #
# Create the OpenMM engine for caffeine
openmm_system = OpenMMEngine(init_openmm=True, topology_format='AMBER', top_file='caffeine.prmtop', crd_format='AMBER', crd_file='caffeine.inpcrd', xml_file="caffeine_sc_iter_22.xml")

# Create ParaMol System
caffeine = ParaMolSystem(name="caffeine", engine=openmm_system, n_atoms=24)

# Load data
caffeine.read_data("../gaff_mod/caffeine_gaff_mod.nc")
caffeine.ref_energies = caffeine.ref_energies[:n_struct]
caffeine.ref_forces = caffeine.ref_forces[:n_struct]
caffeine.ref_coordinates = caffeine.ref_coordinates[:n_struct]
caffeine.n_structures = n_struct


mm_forces_gaff_mod = caffeine.get_forces_ensemble()
qm_forces_gaff_mod = caffeine.ref_forces

atomic_force_error_gaff_mod = np.sqrt(np.mean(np.linalg.norm(mm_forces_gaff_mod-qm_forces_gaff_mod,axis=2)**2,axis=0))


print("GAFF",np.mean(atomic_force_error_gaff/10.0))
print("GAFF.MOD",np.mean(atomic_force_error_gaff_mod/10.0))


# GAFF FORCES
np.savetxt("gaff_forces.dat", atomic_force_error_gaff / 10.0)
np.savetxt("gaff_mod_forces.dat", atomic_force_error_gaff_mod / 10.0)


