import sys
sys.path.insert(0, "/home/jm4g18/ParaMol")

# ParaMol imports
from ParaMol.System.system import *
from ParaMol.MM_engines.openmm import *
from ParaMol.Tasks.adaptive_parametrization import *
from ParaMol.Utils.settings import *
from ParaMol.Utils.Symmetrizers.amber_symmetrizer import *


from ParaMol.Utils.conformational_sampling import *

from os import environ

environ["ASE_ONETEP_COMMAND"] = "export OMP_NUM_THREADS=4; export I_MPI_PMI_LIBRARY=/usr/lib64/libpmi.so; export OMP_STACKSIZE=64M; mpirun -n 5 /mainfs/home/jm4g18/programs/onetep/bin/onetep.iridis5.intel18.omp.scalapack PREFIX.dat >> PREFIX.out 2> PREFIX.err"

# --------------------------------------------------------- #
#                         Preparation                       #
# --------------------------------------------------------- #
# Create the OpenMM engine for caffeine
openmm_system = OpenMMEngine(init_openmm=True, topology_format='AMBER', top_file='caffeine.prmtop', crd_format="AMBER", crd_file='caffeine.inpcrd', xml_file="caffeine_sc_iter_23.xml")

# Create ParaMol System
caffeine = ParaMolSystem(name="caffeine", engine=openmm_system, n_atoms=24)

# Create ParaMol settings instance
paramol_settings = Settings()

# --------------------------------------------------------- #
#                     Set the QM Engine                     #
# --------------------------------------------------------- #
# Create the ASE calculator
from ase.calculators.onetep import *

calc = Onetep(label='caffeine')
calc.set(pseudo_path="/home/jm4g18/recpot")
calc.set(pseudo_suffix='-optgga1.recpot')
calc.set(task='SinglePoint', xc='VV10', cutoff_energy='700 eV')
calc.set(ngwf_threshold_orig="1e-4")
calc.set(ngwf_radius=8.0)


# Alternative, we could set the calculator in the settings
paramol_settings.qm_engine["ase"]["calculator"] = calc


conformational_sampling(paramol_settings, [caffeine], 1000,1000)

caffeine.write_data("caffeine_gaff_mod.nc")

mm_energies_before = caffeine.get_energies_ensemble()
qm_energies = caffeine.ref_energies
rmse_gaff =  np.sqrt(np.mean((mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies)) ** 2))
print("RMSE_GAFF",rmse_gaff,rmse_gaff/4.184)
np.savetxt("qm_energies.dat", qm_energies)
np.savetxt("gaff.dat", mm_energies_before)

