import sys
sys.path.insert(0, "/local/scratch/jm4g18/august2020/ParaMol")

# ParaMol imports
from ParaMol.System.system import *
from ParaMol.MM_engines.openmm import *
from ParaMol.Tasks.adaptive_parametrization import *
from ParaMol.Utils.settings import *
from ParaMol.Utils.amber_symmetrizer import *
from ParaMol.Tasks.ab_initio_properties import *


n_struct = 1000
# --------------------------------------------------------- #
#                         Preparation                       #
# --------------------------------------------------------- #
# Create the OpenMM engine for caffeine
openmm_system = OpenMMEngine(init_openmm=True, topology_format='AMBER', top_file='caffeine.prmtop', crd_file='caffeine.inpcrd')

# Create ParaMol System
caffeine = ParaMolSystem(name="caffeine", engine=openmm_system, n_atoms=24)

# Load data
caffeine.read_data("caffeine_gaff.nc")


# Create ParaMol settings instance
paramol_settings = Settings()


caffeine.ref_energies = caffeine.ref_energies[:n_struct]
caffeine.ref_forces = caffeine.ref_forces[:n_struct]
caffeine.ref_coordinates = caffeine.ref_coordinates[:n_struct]
caffeine.n_structures = n_struct
qm_energies = caffeine.ref_energies
np.savetxt("qm_energies_gaff.dat", qm_energies)
#
mm_energies_before = caffeine.get_energies_ensemble()

# --------------------------------------------------------- #
#                         Preparation                       #
# --------------------------------------------------------- #
# Create the OpenMM engine for caffeine
openmm_system = OpenMMEngine(init_openmm=True, topology_format='XML', top_file='caffeine.prmtop', crd_file='caffeine.inpcrd', xml_file="../caffeine_sc_iter_33.xml")

# Create ParaMol System
caffeine = ParaMolSystem(name="caffeine", engine=openmm_system, n_atoms=24)

# Load data
caffeine.read_data("caffeine_gaff_mod.nc")
caffeine.ref_energies = caffeine.ref_energies[:n_struct]
caffeine.ref_forces = caffeine.ref_forces[:n_struct]
caffeine.ref_coordinates = caffeine.ref_coordinates[:n_struct]
caffeine.n_structures = n_struct

mm_energies_after = caffeine.get_energies_ensemble()


qm_energies = caffeine.ref_energies


np.savetxt("qm_energies_mod.dat", qm_energies)
np.savetxt("gaff.dat", mm_energies_before)
np.savetxt("after.dat", mm_energies_after )

