import seaborn as sns
import numpy as np
import matplotlib.pyplot as plt


sns.set_style("darkgrid")

force = np.loadtxt("force.dat")
energy = np.loadtxt("energy.dat")
reg = np.loadtxt("reg.dat")
rmsd = np.loadtxt("rmsd.dat")


force_before = np.loadtxt("force_before.dat")
energy_before = np.loadtxt("energy_before.dat")
reg_before = np.loadtxt("reg_before.dat")



fig = plt.figure()
fig, axs = plt.subplots(2, sharex=True, figsize=(8,8))

#fig.suptitle('Sharing both axes')
plt.subplots_adjust(wspace=0, hspace=0.04)




N = 24
print(np.arange(1,N).shape, energy_before.shape, force_before.shape)
axs[0].plot(np.arange(1,N),energy_before, label=r"$0.5X_E$ initial", marker="+", color="royalblue", linestyle="--")
axs[0].plot(np.arange(1,N),force_before, label=r"$0.5X_F$ initial", marker="+", color="olivedrab", linestyle="--")
axs[0].plot(np.arange(1,N),reg_before, label=r"$\theta_{L2}$ initial", marker="+", color="tomato", linestyle="--")

axs[0].plot(np.arange(1,N),energy, label=r"$0.5X_E$ final", marker="*", color="royalblue")
axs[0].plot(np.arange(1,N),force, label=r"$0.5X_F$ final", marker="*", color="olivedrab")
axs[0].plot(np.arange(1,N),reg, label=r"$\theta_{L2}$ final", marker="*", color="tomato")
axs[0].legend(ncol=2,loc="upper center")
#axs[0].set_ylim([0,0.11])
#axs[0].set_yticks(np.linspace(2e-2,1e-1,5))

# bottom plot
axs[1].axhline(1e-4, color="black")
axs[1].plot(np.arange(1,N),rmsd, marker="*")
axs[1].set_xlabel("Iteration #")
axs[1].set_ylabel("RMSD of the parameters")


axs[0].set_ylabel("Objective function term")
#axs[1].set_ylim([0,0.015])

axins = axs[1].inset_axes([0.4,0.4,0.6,0.5])
axins.plot(np.arange(1,N)[10:],rmsd[10:], marker="*")
axins.axhline(1e-4, color="black")
#axins.set_xlim([13.3,23.3])
axs[1].indicate_inset_zoom(axins,linewidth=3)

axins.set_xticks(np.arange(1,N,2)[5:])
#axins.set_xticklabels(np.arange(1,N)[14:])

import matplotlib.ticker as mtick
axs[0].yaxis.set_major_formatter(mtick.FormatStrFormatter('%.2e'))
axs[1].yaxis.set_major_formatter(mtick.FormatStrFormatter('%.2e'))
axins.yaxis.set_major_formatter(mtick.FormatStrFormatter('%.2e'))

# Hide x labels and tick labels for all but bottom plot.
for ax in axs:
    ax.set_xticks(np.arange(1,N+2,2))
    ax.set_xlim([0.7,24])

#plt.ylabel(r"$E^{MM}-\langle E^{MM} \rangle$ (kJ/mol)")
#plt.xlabel(r"$E^{QM}-\langle E^{QM} \rangle$ (kJ/mol)")

#plt.legend(loc="upper center")

#plt.axes().set_aspect('equal')
plt.savefig("caffeine_adaptive_convergence_vv10.pdf", pad_inches=0, bbox_inches="tight")
plt.show()



