import numpy as np
import sys
sys.path.insert(0, "/home/treason/PycharmProjects/ParaMol_git_master")
# ParaMol imports
from ParaMol.System.system import *

# ParaMol Tasks imports
from ParaMol.Tasks.torsions_scan import *


# --------------------------------------------------------- #
#                         Preparation                       #
# --------------------------------------------------------- #
# Create the OpenMM engine for norfloxacin
openmm_system = OpenMMEngine(init_openmm=True, topology_format='AMBER', top_file='lig.prmtop', crd_format="AMBER", crd_file='lig.inpcrd')

# Create ParaMol System
norfloxacin = ParaMolSystem(name="norfloxacin", engine=openmm_system, n_atoms=32)
norfloxacin.read_data("norfloxacin_dftb_2d_scan.nc")
np.savetxt("qm_energies.dat", norfloxacin.ref_energies)
# --------------------------------------------------------- #
#                   Parametrize the Torsion                 #
# --------------------------------------------------------- #
torsion_to_scan = [[5,2,9,13]]
torsions_to_freeze = [[9, 6, 2, 5],[5, 2, 9, 13],]


np.savetxt("gaff_qm_relaxed.dat", norfloxacin.get_energies_ensemble())

torsions_scan = TorsionScan()
mm_relaxed_conf = torsions_scan.get_mm_relaxed_conformations(norfloxacin, torsions_to_freeze, tolerance=1.0, max_iter=0, force_constant=9999999., threshold=1.0)
norfloxacin.ref_coordinates = mm_relaxed_conf

gaff_energies = norfloxacin.get_energies_ensemble()
np.savetxt("gaff_mm_relaxed.dat", gaff_energies)

norfloxacin.write_coordinates_xyz("gaff_coord.xyz")
