import matplotlib.pyplot as plt
import numpy as np
import seaborn as sns
from scipy.interpolate import make_interp_spline, BSpline
from scipy.ndimage.filters import gaussian_filter

sns.set_style("darkgrid")

shape=(61,36)
qm_energies = np.loadtxt("norfloxacin_dftb_energies.dat")
mm_energies_before = np.loadtxt("gaff_qm_relaxed.dat")
mm_energies_boltzmann = np.loadtxt("boltzmann/boltzmann.dat")
mm_energies_non_boltzmann = np.loadtxt("non_boltzmann/non_boltzmann.dat")
mm_energies_uniform = np.loadtxt("uniform/uniform.dat")


rmse_gaff =  np.sqrt(np.mean((mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies)) ** 2))
rmse_non_boltzmann =  np.sqrt(np.mean((mm_energies_non_boltzmann - qm_energies - np.mean(mm_energies_non_boltzmann-qm_energies)) ** 2))
rmse_boltzmann =  np.sqrt(np.mean((mm_energies_boltzmann - qm_energies - np.mean(mm_energies_boltzmann-qm_energies)) ** 2))
rmse_uniform =  np.sqrt(np.mean((mm_energies_uniform - qm_energies - np.mean(mm_energies_uniform-qm_energies)) ** 2))



qm_energies = np.loadtxt("norfloxacin_dftb_energies.dat").reshape(shape)
mm_energies_before = np.loadtxt("gaff_qm_relaxed.dat").reshape(shape)
mm_energies_boltzmann = np.loadtxt("boltzmann/boltzmann.dat").reshape(shape)
mm_energies_non_boltzmann = np.loadtxt("non_boltzmann/non_boltzmann.dat").reshape(shape)
mm_energies_uniform = np.loadtxt("uniform/uniform.dat").reshape(shape)

min_angle = -180.0
max_angle = 180.0
step = 10.0
scan = np.arange(min_angle,max_angle,step)





# Form meshgrid
x = np.arange(-180.0, 180.0, 10)
y = np.arange(120, 242, 2)
X, Y = np.meshgrid(x, y)

ms = 40

fig, ((ax1, ax2),(ax3, ax4)) = plt.subplots(2, 2, figsize=(15,10))
#fig.tight_layout()
#for ax in fig.get_axes():
#    ax.label_outer()



min_value = np.min((mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies),mm_energies_uniform - qm_energies - np.mean(mm_energies_uniform-qm_energies),mm_energies_boltzmann - qm_energies - np.mean(mm_energies_boltzmann-qm_energies), mm_energies_non_boltzmann - qm_energies - np.mean(mm_energies_non_boltzmann-qm_energies)))
max_value = np.max((mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies),mm_energies_uniform - qm_energies - np.mean(mm_energies_uniform-qm_energies),mm_energies_boltzmann - qm_energies - np.mean(mm_energies_boltzmann-qm_energies), mm_energies_non_boltzmann - qm_energies - np.mean(mm_energies_non_boltzmann-qm_energies)))



cmap = plt.get_cmap('viridis')

"""
im = ax1.pcolormesh(X, Y, mm_energies_before - np.mean(mm_energies_before), shading="gouraud", cmap=cmap, zorder=0,vmin=min_value,vmax=max_value)
im = ax2.pcolormesh(X, Y, mm_energies_uniform -  np.mean(mm_energies_uniform), shading="gouraud", cmap=cmap, zorder=0,vmin=min_value,vmax=max_value )
im = ax3.pcolormesh(X, Y, mm_energies_boltzmann - np.mean(mm_energies_boltzmann), shading="gouraud", cmap=cmap, zorder=0, vmin=min_value,vmax=max_value)
im = ax4.pcolormesh(X, Y, mm_energies_non_boltzmann - np.mean(mm_energies_non_boltzmann), shading="gouraud", cmap=cmap, zorder=0,vmin=min_value,vmax=max_value)
"""
im = ax1.pcolormesh(X, Y, mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies), shading="gouraud", cmap=cmap, zorder=0,vmin=min_value,vmax=max_value)
im = ax2.pcolormesh(X, Y, mm_energies_uniform - qm_energies - np.mean(mm_energies_uniform-qm_energies), shading="gouraud", cmap=cmap, zorder=0,vmin=min_value,vmax=max_value )
im = ax3.pcolormesh(X, Y, mm_energies_boltzmann - qm_energies - np.mean(mm_energies_boltzmann-qm_energies), shading="gouraud", cmap=cmap, zorder=0, vmin=min_value,vmax=max_value)
im = ax4.pcolormesh(X, Y, mm_energies_non_boltzmann - qm_energies - np.mean(mm_energies_non_boltzmann-qm_energies), shading="gouraud", cmap=cmap, zorder=0,vmin=min_value,vmax=max_value)

levels=10
gauss_filter_param=2.0
cs = ax1.contour(X, Y, gaussian_filter(mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies), gauss_filter_param),levels, colors='k',interpolation='none')
cs = ax2.contour(X, Y, gaussian_filter(mm_energies_uniform - qm_energies - np.mean(mm_energies_uniform-qm_energies), gauss_filter_param), levels, colors='k',interpolation='none')
cs = ax3.contour(X, Y, gaussian_filter(mm_energies_boltzmann - qm_energies - np.mean(mm_energies_boltzmann-qm_energies), gauss_filter_param), levels, colors='k',interpolation='none')
cs = ax4.contour(X, Y, gaussian_filter(mm_energies_non_boltzmann - qm_energies - np.mean(mm_energies_non_boltzmann-qm_energies), gauss_filter_param), levels, colors='k',interpolation='none')
# zoom-in / limit the view to different portions of the data
#ax.set_xlim(-180, 170) # most of the data
#ax.set_ylim([120, 240]) # outliers only

fs_titles = 13
fs = 11
pretext="QM-relaxed, "
ax1.set_title(pretext+"GAFF, RMSE={:5.2f} kJ/mol".format(rmse_gaff),fontsize=fs_titles)
ax2.set_title(pretext+"Uniform weighting, RMSE={:5.2f} kJ/mol".format(rmse_uniform),fontsize=fs_titles)
ax3.set_title(pretext+"Boltzmann weighting, RMSE={:5.2f} kJ/mol".format(rmse_boltzmann),fontsize=fs_titles)
ax4.set_title(pretext+"non-Boltzmann weighting, RMSE={:5.2f} kJ/mol".format(rmse_non_boltzmann),fontsize=fs_titles)





for i in [ax1,ax2,ax3,ax4]:
    i.set_xticks(np.arange(min_angle,max_angle,30))
    i.set_yticks(np.arange(120, 242, 20),) 
    i.set_yticklabels([120,140,160,r"$\pm$180",-160,-140,-120])

# We change the fontsize of minor ticks label 
    i.tick_params(axis='both', which='major', labelsize=fs)
    i.tick_params(axis='both', which='minor', labelsize=fs)

#cbar_ax = fig.add_axes([0.85, 0.15, 0.05, 0.7])
#fig.colorbar(im, cax=cbar_ax)

fig.subplots_adjust(right=0.85)
cbar_ax = fig.add_axes([0.88, 0.15, 0.04, 0.7])

cb=fig.colorbar(im, cax=cbar_ax)
cb.set_label("$E^{MM}-E^{QM}- \langle E^{MM}-E^{QM} \\rangle $ (kJ/mol)", size=fs_titles)#,rotation=270)	
fig.text(0.5, 0.06, 'C5-N4-C2-C1 dihedral angle (degrees)', ha='center', fontsize=fs_titles)
fig.text(0.08, 0.5, 'C2-C6-N4-C5 dihedral angle (degrees)', va='center', rotation='vertical', fontsize=fs_titles)

plt.subplots_adjust(wspace=0.1, hspace=0.2)
plt.savefig('norfloxacin_dftb_fittings_qm_relaxed.pdf', format='pdf', bbox_inches="tight", pad_inches=0.0)
plt.show()




