import numpy as np
import sys
sys.path.insert(0, "/home/treason/PycharmProjects/ParaMol_git_master")
# ParaMol imports
from ParaMol.System.system import *
from ParaMol.MM_engines.openmm import *
from ParaMol.QM_engines.qm_engine import *

# ParaMol Tasks imports
from ParaMol.Tasks.parametrization import *
from ParaMol.Tasks.torsions_scan import *
from ParaMol.Utils.settings import *


# --------------------------------------------------------- #
#                         Preparation                       #
# --------------------------------------------------------- #
seeds = ["non_boltzmann", "boltzmann", "uniform"]
torsions_to_freeze = [[9, 6, 2, 5],[5, 2, 9, 13],]
for seed in seeds:
    # Create the OpenMM engine for norfloxacin
    openmm_system = OpenMMEngine(init_openmm=True, topology_format='AMBER', top_file="lig.prmtop", crd_format='AMBER', crd_file='lig.inpcrd', xml_file="norfloxacin_{}.xml".format(seed))

    # Create ParaMol System
    norfloxacin = ParaMolSystem(name="norfloxacin", engine=openmm_system, n_atoms=32)

    # Relax

    norfloxacin.read_data("norfloxacin_dftb_2d_scan.nc")
    torsions_scan = TorsionScan()
    mm_relaxed_conf = torsions_scan.get_mm_relaxed_conformations(norfloxacin, torsions_to_freeze, tolerance=0.01, max_iter=0, force_constant=9999999., threshold=1.0)
    norfloxacin.ref_coordinates = mm_relaxed_conf

    # Calculate energies
    mm_energies = norfloxacin.get_energies_ensemble()
    np.savetxt("{}.dat".format(seed), mm_energies)
