import matplotlib.pyplot as plt
import numpy as np
import seaborn as sns
from scipy.interpolate import make_interp_spline, BSpline
from scipy.ndimage.filters import gaussian_filter

sns.set_style("darkgrid")

shape=(61,36)
qm_energies = np.loadtxt("qm_energies.dat")
gaff_qm = np.loadtxt("gaff_qm_relaxed.dat")
gaff_mm = np.loadtxt("gaff_mm_relaxed.dat")





qm_energies = np.loadtxt("qm_energies.dat").reshape(shape)
gaff_qm = np.loadtxt("gaff_qm_relaxed.dat").reshape(shape)
gaff_mm = np.loadtxt("gaff_mm_relaxed.dat").reshape(shape)


min_angle = -180.0
max_angle = 180.0
step = 10.0
scan = np.arange(min_angle,max_angle,step)





# Form meshgrid
x = np.arange(-180.0, 180.0, 10)
y = np.arange(120, 242, 2)
X, Y = np.meshgrid(x, y)

ms = 40

fig, ((ax1, ax2),(ax3, ax4)) = plt.subplots(2, 2, figsize=(15,10))
#fig.tight_layout()
#for ax in fig.get_axes():
#    ax.label_outer()



min_value = np.min( (qm_energies-np.mean(qm_energies),gaff_qm-np.mean(gaff_qm),gaff_mm-np.mean(gaff_mm)) )
max_value = np.max( (qm_energies-np.mean(qm_energies),gaff_qm-np.mean(gaff_qm),gaff_mm-np.mean(gaff_mm)) )


cmap = plt.get_cmap('viridis')


im = ax1.pcolormesh(X, Y, qm_energies - np.mean(qm_energies), shading="gouraud", cmap=cmap, zorder=0,vmin=min_value,vmax=max_value)
im = ax2.pcolormesh(X, Y, gaff_qm - np.mean(gaff_qm), shading="gouraud", cmap=cmap, zorder=0,vmin=min_value,vmax=max_value )
im = ax3.pcolormesh(X, Y, gaff_mm - np.mean(gaff_mm), shading="gouraud", cmap=cmap, zorder=0, vmin=min_value,vmax=max_value)


levels=10
gauss_filter_param=2
cs = ax1.contour(X, Y, gaussian_filter(qm_energies - np.mean(qm_energies), gauss_filter_param),levels, colors='k',interpolation='none')
cs = ax2.contour(X, Y, gaussian_filter(gaff_qm - np.mean(gaff_qm), gauss_filter_param), levels, colors='k',interpolation='none')
cs = ax3.contour(X, Y, gaussian_filter(gaff_mm - np.mean(gaff_mm), gauss_filter_param), levels, colors='k',interpolation='none')

fs_titles = 13
fs = 11
pretext=""
ax1.set_title(pretext+"SCC-DFTB-D3",fontsize=fs_titles)
ax2.set_title(pretext+"GAFF QM relaxed",fontsize=fs_titles)
ax3.set_title(pretext+"GAFF MM relaxed",fontsize=fs_titles)



#fig.text(0.5, 0.06, 'C5-N4-C2-C1 dihedral angle (degrees)', ha='center', fontsize=fs_titles)

ax3.set_xlabel("C5-N4-C2-C1 dihedral angle (degrees)", fontsize=fs_titles)
ax2.set_xlabel("C5-N4-C2-C1 dihedral angle (degrees)", fontsize=fs_titles)
ax4.axis('off')

for i in [ax1,ax2,ax3]:
    i.set_xticks(np.arange(min_angle,max_angle,30))
    i.set_yticks(np.arange(120, 242, 20),) 
    i.set_yticklabels([120,140,160,r"$\pm$180",-160,-140,-120])

# We change the fontsize of minor ticks label 
    i.tick_params(axis='both', which='major', labelsize=fs)
    i.tick_params(axis='both', which='minor', labelsize=fs)

#cbar_ax = fig.add_axes([0.85, 0.15, 0.05, 0.7])
#fig.colorbar(im, cax=cbar_ax)

fig.subplots_adjust(right=0.85)
cbar_ax = fig.add_axes([0.88, 0.15, 0.04, 0.7])

cb=fig.colorbar(im, cax=cbar_ax)
cb.set_label("$E- \langle E \\rangle $ (kJ/mol)", size=fs_titles)#,rotation=270)	


fig.text(0.5, 0.06, r'$\phi$, C5-N4-C2-C1 dihedral angle (degrees)', ha='center', fontsize=fs_titles)
fig.text(0.08, 0.5, r'$\psi$, C2-C6-N4-C5 dihedral angle (degrees)', va='center', rotation='vertical', fontsize=fs_titles)


#fig.text(0.08, 0.5, 'C2-C6-N4-C5 dihedral angle (degrees)', va='center', rotation='vertical', fontsize=fs_titles)

plt.subplots_adjust(wspace=0.1, hspace=0.2)
plt.savefig('norfloxacin_dftb_fittings_qm_relaxed.pdf', format='pdf', bbox_inches="tight", pad_inches=0.0)
plt.show()




