import matplotlib.pyplot as plt
import numpy as np
import seaborn as sns
from scipy.interpolate import make_interp_spline, BSpline

sns.set()
qm_energies = np.loadtxt("norfloxacin_wb97xd_energies.dat")
mm_energies_before = np.loadtxt("gaff_qm_relaxed.dat")
mm_energies_boltzmann = np.loadtxt("boltzmann/boltzmann.dat")

mm_energies_uniform = np.loadtxt("uniform/uniform.dat")

min_angle = -180.0
max_angle = 180.0
step = 10.0
scan = np.arange(min_angle,max_angle,step)

ms = 20

fig, ((ax1, ax2)) = plt.subplots(2, 1, figsize=(8,7))

for ax in fig.get_axes():
    ax.label_outer()




# 300 represents number of points to make between T.min and T.max
xnew = np.linspace(scan.min(), scan.max(), 1000) 

spl = make_interp_spline(scan, np.asarray(qm_energies) - np.mean(qm_energies),  k=5)  # type: BSpline
power_smooth = spl(xnew)
ax1.plot(xnew, power_smooth, label="SCC-DFTB-D3", color="black")
ax1.scatter(scan, np.asarray(qm_energies) - np.mean(qm_energies), marker='*',s=ms, color="black")


rmse_gaff =  np.sqrt(np.mean((mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies)) ** 2))

rmse_boltzmann =  np.sqrt(np.mean((mm_energies_boltzmann - qm_energies - np.mean(mm_energies_boltzmann-qm_energies)) ** 2))
rmse_uniform =  np.sqrt(np.mean((mm_energies_uniform - qm_energies - np.mean(mm_energies_uniform-qm_energies)) ** 2))







spl = make_interp_spline(scan, np.asarray(mm_energies_before) - np.mean(mm_energies_before),  k=5)  # type: BSpline
power_smooth = spl(xnew)
ax1.plot(xnew, power_smooth, label="GAFF, RMSE={:5.2f} kJ/mol".format(rmse_gaff), color="red")
ax1.scatter(scan, np.asarray(mm_energies_before) - np.mean(mm_energies_before), marker='*',s=ms, color="red")


spl = make_interp_spline(scan, np.asarray(mm_energies_boltzmann) - np.mean(mm_energies_boltzmann),  k=5)  # type: BSpline
power_smooth = spl(xnew)
ax1.plot(xnew, power_smooth,label="Boltzmann weighting, RMSE={:5.2f} kJ/mol".format(rmse_boltzmann), color="blue")
ax1.scatter(scan, np.asarray(mm_energies_boltzmann) - np.mean(mm_energies_boltzmann), marker='*', s=ms, color="blue")




spl = make_interp_spline(scan, np.asarray(mm_energies_uniform) - np.mean(mm_energies_uniform),  k=5)  # type: BSpline
power_smooth = spl(xnew)
ax1.plot(xnew, power_smooth,label="Uniform weighting, RMSE={:5.2f} kJ/mol".format(rmse_uniform), color="purple")
ax1.scatter(scan, np.asarray(mm_energies_uniform) - np.mean(mm_energies_uniform), marker='*', s=ms, color="purple")




# scan = np.(len(qm_energies))

print("rmse_gaff",rmse_gaff)

print("rmse_boltzmann",rmse_boltzmann)
print("rmse_uniform",rmse_uniform)


spl = make_interp_spline(scan, mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies),  k=5)  # type: BSpline
power_smooth = spl(xnew)
ax2.plot(xnew, power_smooth, label="GAFF, RMSE={:5.2f} kJ/mol".format(rmse_gaff), color="red")
ax2.scatter(scan, mm_energies_before - qm_energies - np.mean(mm_energies_before-qm_energies), marker='*',s=ms, color="red")



spl = make_interp_spline(scan, mm_energies_boltzmann- qm_energies - np.mean(mm_energies_boltzmann-qm_energies),  k=5)  # type: BSpline
power_smooth = spl(xnew)
ax2.plot(xnew, power_smooth,label="Boltzmann weighting, RMSE={:5.2f} kJ/mol".format(rmse_boltzmann), color="blue")
ax2.scatter(scan, mm_energies_boltzmann- qm_energies - np.mean(mm_energies_boltzmann-qm_energies), marker='*', s=ms, color="blue")




spl = make_interp_spline(scan, mm_energies_uniform- qm_energies - np.mean(mm_energies_uniform-qm_energies),  k=5)  # type: BSpline
power_smooth = spl(xnew)
ax2.plot(xnew, power_smooth,label="Uniform weighting, RMSE={:5.2f} kJ/mol".format(rmse_uniform), color="purple")
ax2.scatter(scan, mm_energies_uniform- qm_energies - np.mean(mm_energies_uniform-qm_energies), marker='*', s=ms, color="purple")



ax1.legend(loc='upper left', bbox_to_anchor=(-0.09, 1.30), ncol=2,
            borderaxespad=0, frameon=True, prop={'size': 10})

plt.xlabel("C5-N4-C2-C1 dihedral angle (degrees)".format())
#plt.legend()
# plt.ylim([0,100])
ax1.set_ylabel("$E-\langle E \\rangle $ (kJ/mol)")
#ax1.get_yaxis().set_label_coords(-0.1,0.1)
ax2.set_ylabel("$E^{MM}-E^{QM}- \langle E^{MM}-E^{QM} \\rangle $ (kJ/mol)")
#ax2.get_yaxis().set_label_coords(-0.1,0.1)

plt.xticks(np.arange(min_angle,max_angle+30,30))
plt.subplots_adjust(wspace=0.0,hspace=0.1)
plt.savefig('norfloxacin_wb97xd_fittings_mm_relaxed.pdf', format='pdf', bbox_inches="tight", pad_inches=0.0)

plt.show()


